@@ -35,6 +35,7 @@ typedef enum pu_config_option_t {
 
   PU_CONFIG_OPTION_CLEANMETHOD,
   PU_CONFIG_OPTION_COLOR,
+  PU_CONFIG_OPTION_NOPROGRESSBAR,
   PU_CONFIG_OPTION_USESYSLOG,
   PU_CONFIG_OPTION_CHECKSPACE,
   PU_CONFIG_OPTION_VERBOSEPKGLISTS,
@@ -56,9 +57,13 @@ typedef enum pu_config_option_t {
   PU_CONFIG_OPTION_CACHEDIRS,
 
   PU_CONFIG_OPTION_SERVER,
+  PU_CONFIG_OPTION_CACHESERVER,
 
   PU_CONFIG_OPTION_USAGE,
 
+  PU_CONFIG_OPTION_DOWNLOADUSER,
+  PU_CONFIG_OPTION_DISABLESANDBOX,
+
   PU_CONFIG_OPTION_INCLUDE
 } pu_config_option_t;
 
@@ -80,15 +85,18 @@ typedef struct pu_config_t {
   char *gpgdir;
   char *logfile;
   char *xfercommand;
+  char *downloaduser;
 
   int paralleldownloads;
 
   pu_config_bool_t checkspace;
   pu_config_bool_t color;
+  pu_config_bool_t noprogressbar;
   pu_config_bool_t ilovecandy;
   pu_config_bool_t usesyslog;
   pu_config_bool_t verbosepkglists;
   pu_config_bool_t disabledownloadtimeout;
+  pu_config_bool_t disablesandbox;
 
   int siglevel;
   int localfilesiglevel;
@@ -116,6 +124,7 @@ typedef struct pu_config_t {
 typedef struct pu_repo_t {
   char *name;
   alpm_list_t *servers;
+  alpm_list_t *cacheservers;
   int usage;
   int siglevel;
   int siglevel_mask;
@@ -162,5 +171,3 @@ int pu_config_reader_next(pu_config_reader_t *reader);
 void pu_config_reader_free(pu_config_reader_t *reader);
 
 #endif /* PACUTILS_CONFIG_H */
-
-/* vim: set ts=2 sw=2 et: */
